( cd usr/lib/teTeX/info ; rm -rf localdir )
( cd usr/lib/teTeX/info ; ln -sf dir localdir )
( cd usr/lib/teTeX/man ; rm -rf cat1 )
( cd usr/lib/teTeX/man ; ln -sf /var/man/cat1 cat1 )
( cd usr/lib/teTeX/man ; rm -rf cat5 )
( cd usr/lib/teTeX/man ; ln -sf /var/man/cat5 cat5 )
( cd usr/lib/teTeX/texmf/doc ; rm -rf index.html )
( cd usr/lib/teTeX/texmf/doc ; ln -sf helpindex.html index.html )
